from distutils.core import setup, Extension
setup (name="pysmbc",
       version="1.0.7",
       description="Python bindings for libsmbclient",
       author="Tim Waugh",
       author_email="twaugh@redhat.com",
       maintainer="Tim Waugh",
       maintainer_email="twaugh@redhat.com",
       url="http://cyberelk.net/tim/software/pysmbc/",
       download_url="http://cyberelk.net/tim/data/pysmbc/",
       classifiers=[
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: GNU General Public License (GPL)",
        "Development Status :: 5 - Production/Stable",
        "Operating System :: Unix",
        "Programming Language :: C",
        ],
       license="GPLv2+",
       ext_modules=[Extension("smbc",
                              ["smbcmodule.c",
                               "context.c",
                               "dir.c",
                               "file.c",
                               "smbcdirent.c"],
                              libraries=["smbclient"])])
